@@ -1,12 +1,11 @@
 from rest_framework.serializers import SerializerMethodField
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
 
-EventSpeaker = import_string(api_settings.EVENT['speaker']['models'])
-EventSpeakerSerializer = import_string(
-    api_settings.EVENT['speaker']['serializers'])
-EventSchedule = import_string(api_settings.EVENT['schedule']['models'])
+
+EventSpeaker = import_string('EVENT.speaker.models')
+EventSpeakerSerializer = import_string('EVENT.speaker.serializers')
+EventSchedule = import_string('EVENT.schedule.models')
 
 
 class EventScheduleSerializer(CustomSerializer):
