@@ -1,12 +1,12 @@
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
 
-EventVenue = import_string(api_settings.EVENT['venue']['models'])
+
+EventVenue = import_string('EVENT.venue.models')
 
 
 class EventVenueSerializer(CustomSerializer):
 
     class Meta:
         model = EventVenue
-        fields = '__all__'
\ No newline at end of file
+        fields = '__all__'
