@@ -40,6 +40,13 @@ class EventVoteView(CustomModelViewSet):
             headers = self.get_success_headers(serializer.data)
             return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
 
+    def list(self, request, *args, **kwargs):
+        schedule_id = request.query_params.get('schedule_id', None)
+        queryset = self.model_class.objects.filter(
+            schedule_id=schedule_id).first()
+        serializer = self.get_serializer(queryset)
+        return Response(serializer.data)
+
 
 class EventVoteUserView(CustomModelViewSet):
     model_class = EventVoteUser
