@@ -7,7 +7,7 @@ from bluedot_rest_framework import import_string
 class WechatLoginConsumer(WebsocketConsumer):
     def connect(self):
         self.scene_str = self.scope['url_route']['kwargs']['scene_str']
-        self.room_group_name = 'login_%s' % self.scene_str
+        self.room_group_name = 'pc_login_%s' % self.scene_str
 
         # Join room group
         async_to_sync(self.channel_layer.group_add)(
@@ -28,9 +28,7 @@ class WechatLoginConsumer(WebsocketConsumer):
     def receive(self, text_data):
         text_data_json = json.loads(text_data)
         data = {
-            'scene_str': self.scene_str,
             'token': text_data_json.get('token', None)
-
         }
 
         # Send message to room group
