@@ -8,12 +8,13 @@ from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
 from wechatpy import parse_message, create_reply, utils
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
+from bluedot_rest_framework.utils.func import orm_bulk_update
+
 from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
 from .models import WeChatUser
-User = import_string(api_settings.USER['models'])
+User = import_string('USER.models')
 
 
 class JSSdk(APIView):
@@ -109,9 +110,9 @@ class OAuth(APIView):
             }
 
             wechat_queryset = WeChatUser.objects.filter(
-                openid=user_info['openid'])
+                openid=user_info['openid']).first()
             if wechat_queryset:
-                wechat_queryset.update(**user_data)
+                orm_bulk_update(wechat_queryset, user_data)
             else:
                 wechat_queryset = WeChatUser.objects.create(**user_data)
             user_id = 0
